Bootstrap Components › Carousel — Stisla

# Carousel

A slideshow component for cycling through elements—images or slides of text—like a carousel.

#### Simple

#### Navigation & Indicator

Previous Next

#### Caption

##### Heading

Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.

##### Heading

Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.

##### Heading

Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.

Previous Next

#### Crossfade

Previous Next